@@ -210,15 +210,16 @@ dynamicforms = {
     $('.modal-backdrop').remove();
     $('#df-overlay').hide();
     if (dynamicforms.progressDlgShown) {
-      dynamicforms.progressDlgShown = false;
+      dynamicforms.progressDlgShown        = false;
       dynamicforms.progressDlgStartShowing = false;
 
-    var $dlg = $('#' + progressDlgID);
-    if($dlg.length) {
-      if (dynamicforms.DYNAMICFORMS.jquery_ui) {
-        $dlg.dialog('close');
-      } else {
-        $dlg.remove();
+      var $dlg = $('#' + progressDlgID);
+      if ($dlg.length) {
+        if (dynamicforms.DYNAMICFORMS.jquery_ui) {
+          $dlg.dialog('close');
+        } else {
+          $dlg.remove();
+        }
       }
     }
     dynamicforms.progressDlgOverlay = false;
@@ -1433,7 +1434,7 @@ dynamicforms = {
 
     if (!$col.hasClass('ordering')) return;  // Only process columns that are sortable
 
-    event.stopPropagation();
+    this.stopEventPropagation(event);
 
     function renumber() {
       for (var i = 0; i < ordering.length; i++)
@@ -1665,7 +1666,7 @@ dynamicforms = {
     };
   },
 
-  showModalDialog: function showModalDialog(title, body, buttons) {
+  showModalDialog: function showModalDialog(title, body, buttons, size) {
     var $dlg = $("#df-modal-dialog-container").clone();
     $dlg.attr('id', 'dialog-' + dynamicforms.slugify(title));
     $(document.body).append($dlg);
@@ -1725,10 +1726,21 @@ dynamicforms = {
 
       dialog.dialog("open");
     } else {
+      if(size != undefined && size != '')
+        $dlg.find('div.modal-dialog').addClass('modal-' + size);
       $dlg.modal();
     }
 
   },
+  stopEventPropagation: function stopEventPropagation(e){
+    if (!e) {
+        e = window.event;
+    }
+    e.cancelBubble = true;
+    if (e.stopPropagation) {
+        e.stopPropagation();
+    }
+  }
 };
 
 $(document).ready(function () {
